@@ -211,7 +211,7 @@ int ss_em_EM(double **x, int n, int p, int nclass, double *pi, double **Mu,
 */
     meandispersion_MLE(x, n, p, Mu[0], LTSigma[0]);
     like = -0.5 * n * p - 0.5 * n * log(determinant(LTSigma[0], p)) -
-           0.5 * n * p * log(2 * PI);
+           0.5 * n * p * log(2 * M_PI);
     *llhdval = like;
   }
   else {
